<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/textwheel.git

return [

	// R
	'retour_ligne_auto' => 'Retour ligne automatique',
	'retour_ligne_ignore' => 'Retour ligne ignoré',
	'retour_ligne_manuel' => 'Retour ligne manuel',
];
